/*
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This code is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this code; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.  */

/* Copyright (C) 2002 Ian Zimmerman <itz@speakeasy.org> */

#ifndef INCLUDE_MY_CLIST_HH
#define INCLUDE_MY_CLIST_HH

/* $Id: my_clist.hh,v 1.1 2002/09/09 18:30:15 itz Exp $ */

#include <gtk--/clist.h>
#include <vector>

struct sys_color;

class my_clist : public Gtk::CList {
public:
  my_clist(const char* rgb_file_name);
  void fill(gdouble red, gdouble green, gdouble blue);
  void color_change(gdouble red, gdouble green, gdouble blue);
  int find_first(const char* s);
  int find_next(const char* s);
  const gdouble* get_selected_color();
private:
  void add_all_colors();
  
  vector<sys_color*> colors;
  int has_selection;
  gdouble selected_color[4];
  int last_found;
  
  typedef Gtk::CList inherited;

  enum sorted { none, num_inc, num_dec, name_inc, name_dec, bright_inc, bright_dec, dist_inc, dist_dec };
  sorted sorted_by;
  void fill_internal();
  void sort_by_num_inc();
  void sort_by_num_dec();
  void sort_by_name_inc();
  void sort_by_name_dec();
  void sort_by_bright_inc();
  void sort_by_bright_dec();
  void sort_by_dist_inc();
  void sort_by_dist_dec();
protected:
  virtual void select_row_impl(gint row, gint column, GdkEvent* p);
  virtual void unselect_row_impl(gint row, gint column, GdkEvent* p);
  virtual void click_column_impl(gint column);
};

#endif // INCLUDE_MY_CLIST_HH
